@@ -114,7 +114,7 @@ class TemporaryDirectory:
         """
         self.__dir = tempfile.mkdtemp("-tempdir", "duplicity-", temproot)
 
-        log.Log("Using temporary directory %s" % (self.__dir,), 5)
+        log.Log(_("Using temporary directory %s") % (self.__dir,), 5)
 
         # number of mktemp()/mkstemp() calls served so far
         self.__tempcount = 0
@@ -150,7 +150,7 @@ class TemporaryDirectory:
             suffix = "-%d" % (self.__tempcount,)
             filename = tempfile.mktemp(suffix, "mktemp-", self.__dir)
 
-            log.Log("Registering (mktemp) temporary file %s" % (filename,), 9)
+            log.Log(_("Registering (mktemp) temporary file %s") % (filename,), 9)
             self.__pending[filename] = None
         finally:
             self.__lock.release()
@@ -172,7 +172,7 @@ class TemporaryDirectory:
             suffix = "-%d" % (self.__tempcount,)
             fd, filename = tempfile.mkstemp(suffix, "mkstemp-", self.__dir)
 
-            log.Log("Registering (mkstemp) temporary file %s" % (filename,), 9)
+            log.Log(_("Registering (mkstemp) temporary file %s") % (filename,), 9)
             self.__pending[filename] = None
         finally:
             self.__lock.release()
@@ -204,10 +204,10 @@ class TemporaryDirectory:
         self.__lock.acquire()
         try:
             if self.__pending.has_key(fname):
-                log.Log("Forgetting temporary file %s" % (fname, ), 9)
+                log.Log(_("Forgetting temporary file %s") % (fname, ), 9)
                 del(self.__pending[fname])
             else:
-                log.Log("Attempt to forget unknown tempfile %s - this is probably a bug." % (fname,), 1)
+                log.Log(_("Attempt to forget unknown tempfile %s - this is probably a bug.") % (fname,), 1)
                 pass
         finally:
             self.__lock.release()
@@ -226,15 +226,15 @@ class TemporaryDirectory:
             if not self.__dir is None:
                 for file in self.__pending.keys():
                     try:
-                        log.Log("Removing still remembered temporary file %s" % (file,), 9)
+                        log.Log(_("Removing still remembered temporary file %s") % (file,), 9)
                         os.unlink(file)
                     except:
-                        log.Log("Cleanup of temporary file %s failed" % (file,), 7)
+                        log.Log(_("Cleanup of temporary file %s failed") % (file,), 7)
                         pass
                 try:
                     os.rmdir(self.__dir)
                 except:
-                    log.Log("Cleanup of temporary directory %s failed - this is probably a bug." % (self.__dir,), 1)
+                    log.Log(_("Cleanup of temporary directory %s failed - this is probably a bug.") % (self.__dir,), 1)
                     pass
                 self.__pending = None
                 self.__dir = None
